# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test;
BEGIN { plan tests => 5 };
use RTF::HTML::Converter::API;
ok(1); # If we made it this far, we're ok.

#########################

my $rtf = new RTF::HTML::Converter::API (dir => "t");
ok($rtf);
$rtf->process;
ok(1);
ok('rtf-test.rtf', $rtf->{files}[0]->{filename} );
ok($rtf->{files}[0]->{html}, <<__END_HTML__
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" []>
<html>
<body>

<p ALIGN=LEFT>This is a test document.</p>

<H1 ALIGN=LEFT><b>Heading One.</b></H1>

<H2 ALIGN=LEFT><i><b>Heading Two.</i></b></H2>

<H3 ALIGN=LEFT><b>Heading Three.</b></H3>

<H3 ALIGN=LEFT></i><i>Italic.</i></H3>

<H3 ALIGN=LEFT></i></b><b>Bold.</b></H3>

<H3 ALIGN=LEFT></b>Indented one tab.</H3>
<p><b>Author</b> : LG</p>
<p><b>Creation date</b>: 2002-2-24-19-54</p>
<p><b>Modification date</b>: 2002-2-24-19-55</p>
</body>
</html>
__END_HTML__
);

